embassy-stm32

Crates

git

Versions

stm32f413rg

Flavors

FSMC

Struct FSMC 

pub struct FSMC { /* private fields */ }
FSMC peripheral

Implementations

Source

impl FSMC

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.