embassy-stm32

Crates

git

Versions

stm32f413rg

Flavors

TIM13

Struct TIM13 

pub struct TIM13 { /* private fields */ }
TIM13 peripheral

Implementations

Source

impl TIM13

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.